@@ -1,4 +1,4 @@
-from django.utils.translation import ugettext_lazy as _
+from django.utils.text import capfirst
 from taggit.forms import TagField
 from taggit.managers import TaggableManager as BaseTaggableManager
 from taggit_autosuggest.widgets import TagAutoSuggest
@@ -8,11 +8,10 @@ class TaggableManager(BaseTaggableManager):
 
     def formfield(self, form_class=TagField, **kwargs):
         defaults = {
-            "label": _("Tags"),
-            "help_text": _("A comma-separated list of tags."),
+            "label": capfirst(self.verbose_name),
+            "help_text": self.help_text,
             "required": not self.blank,
             "widget": TagAutoSuggest(),
         }
         defaults.update(kwargs)
-
         return form_class(**defaults)
